AutoArchive._ui — AutoArchive Developer Manual (ver. 1.2.1)

### Navigation

- index
- modules |
- next |
- previous |
- AutoArchive Developer Manual (ver. 1.2.1) »
- API Reference »
- AutoArchive »

# AutoArchive._ui

Base package for user interfaces.

Provides all concrete user interface packages such as `cmdline` for the command-line user interface.

## Sub-Packages

- AutoArchive._ui._cmdline

### Navigation

- index
- modules |
- next |
- previous |
- AutoArchive Developer Manual (ver. 1.2.1) »
- API Reference »
- AutoArchive »